@@ -49,20 +49,20 @@ def _edge_collection(*hics, region=None, scale=True,
 
     total_edges = sum(len(hic.edges) for hic in hics)
 
-    if isinstance(region, GenomicRegion) or isinstance(region, string_types):
+    if isinstance(region, GenomicRegion) or isinstance(region, string_types) or region is None:
         regions = [region]
     else:
         regions = region
 
     region_pairs = []
     for i in range(len(regions)):
-        region1 = as_region(regions[i])
+        region1 = as_region(regions[i]) if regions[i] is not None else None
         if region1 is None:
             region_pairs.append(None)
             continue
 
         for j in range(i, len(regions)):
-            region2 = as_region(regions[j])
+            region2 = as_region(regions[j]) if regions[j] is not None else None
             if not inter_chromosomal and region1.chromosome != region2.chromosome:
                 continue
             region_pairs.append((region1, region2))
@@ -74,7 +74,8 @@ def _edge_collection(*hics, region=None, scale=True,
             logger.debug("Adding Hic {} ({}) to edge collection".format(i, region))
 
             for region_pair in region_pairs:
-                for edge in hic.edges(region_pair, lazy=True, **kwargs):
+                for edge in hic.edges(region_pair, lazy=True,
+                                      inter_chromosomal=inter_chromosomal, **kwargs):
                     weight = edge.weight * scaling_factors[i]
                     source, sink = edge.source, edge.sink
 
@@ -233,6 +234,33 @@ class ComparisonMatrix(RegionMatrixTable):
     def from_matrices(cls, matrix1, matrix2, file_name=None, tmpdir=None,
                       log_cmp=False, ignore_infinite=True, ignore_zeros=False,
                       scale=True, **kwargs):
+        """
+        Create a comparison matrix from two compatible matrix objects.
+
+        The resulting object can be treated like any other matrix in
+        FAN-C, offering the same convenience functions for regions and
+        edges.
+
+        :param matrix1: First matrix object, such as a Hi-C matrix
+        :param matrix2: Second matrix object, such as a Hi-C matrix
+        :param file_name: Path to the comparison output file
+        :param tmpdir: Optional. If ``True``, will work in temporary
+                       directory until file is closed
+        :param log_cmp: If ``True``, log2-transform the comparison matrix
+                        value after the comparison has been performed. Useful,
+                        for example, for fold-change matrices
+        :param ignore_infinite: If ``True``, will remove infinite values from
+                                the final comparison matrix
+        :param ignore_zeros: If ``True``, will only compare edge weights when
+                             both are non-zero.
+        :param scale: Scale matrices to the same sequencing depth (sum of all
+                      edge weights) before the comparison. You can set this
+                      to ``False`` if you know the type of normalisation you
+                      performed already takes care of this.
+        :param kwargs: Keyword arguments passed to
+                       :func:`~fanc.matrix.RegionPairsContainer.edges`
+        :return: :class:`~fanc.architecture.comparisons.ComparisonMatrix`
+        """
         kwargs['lazy'] = True
 
         comparison_matrix = cls(file_name=file_name, mode='w', tmpdir=tmpdir)
@@ -345,7 +373,23 @@ class ComparisonScores(RegionScoreParameterTable):
 
     @classmethod
     def from_scores(cls, scores1, scores2, attributes=None, file_name=None, tmpdir=None,
-                    log=False, field_prefix='cmp_', *args, **kwargs):
+                    log=False, field_prefix='cmp_', **kwargs):
+        """
+        Compare parameter-based scores in a :class:`~fanc.architecture.domains.RegionScoreParameterTable`.
+
+        :param scores1: First :class:`~fanc.architecture.domains.RegionScoreParameterTable`
+        :param scores2: Second :class:`~fanc.architecture.domains.RegionScoreParameterTable`
+        :param attributes: If ``None``, will do all possible comparisons. Provide a list of
+                           region attributes (e.g. ["insulation_1000000", "insulation_2000000"])
+                           for specific comparisons.
+        :param file_name: Optional path to an output file
+        :param tmpdir: Optional. If ``True``, will work in temporary
+                       directory until file is closed
+        :param log: log2-transform values after comparison
+        :param field_prefix: Prefix of the output field
+        :param kwargs: Keyword arguments passed on to :func:`~genomic_regions.RegionBased.regions`
+        :return: :class:`~fanc.architecture.comparisons.ComparisonScores`
+        """
         # all matching parameters
         if attributes is None:
             attributes = []
@@ -364,7 +408,7 @@ class ComparisonScores(RegionScoreParameterTable):
             region_ixs[(region.chromosome, region.start, region.end)] = len(region_pairs)
             region_pairs.append([region, None])
 
-        for region in scores2.regions:
+        for region in scores2.regions(**kwargs):
             ix = region_ixs[(region.chromosome, region.start, region.end)]
             region_pairs[ix][1] = region
 
@@ -425,14 +469,36 @@ class ComparisonRegions(RegionsTable):
 
     @classmethod
     def from_regions(cls, region_based1, region_based2, attribute='score',
-                     file_name=None, tmpdir=None, log=False, score_field='score',
-                     *args, **kwargs):
+                     file_name=None, tmpdir=None, log=False, score_field=None,
+                     **kwargs):
+        """
+        Compare genomic tracks with region-associated scores.
+
+        All scores are assumed to be floats.
+
+        :param region_based1: First :class:`~genomic_regions.RegionBased` object
+        :param region_based2: Second :class:`~genomic_regions.RegionBased` object
+        :param attribute: Name of the attribute to be compared. Typically "score"
+        :param file_name: Optional path to an output file
+        :param tmpdir: Optional. If ``True``, will work in temporary
+                       directory until file is closed
+        :param log: If ``True``, will log2-transform values after comparison
+        :param score_field: Name of the attribute comparison scores will be saved to.
+                            Will use ``attribute`` if not provided.
+        :param kwargs: Keyword arguments passed on to :func:`~genomic_regions.RegionBased.regions`
+        :return: :class:`~fanc.architecture.comparisons.ComparisonRegions`
+        """
+        if score_field is None:
+            score_field = attribute
+
+        logger.debug("Using scores from '{}' field, writing to '{}' field".format(attribute, score_field))
+
         comparison_regions = cls(file_name=file_name, mode='w', tmpdir=tmpdir,
                                  additional_fields={attribute: tables.Float32Col()})
         comparison_regions.add_regions(region_based1.regions, preserve_attributes=False)
 
         regions = dict()
-        for region in region_based1.regions:
+        for region in region_based1.regions(**kwargs):
             regions[(region.chromosome, region.start, region.end)] = region
 
         scores = []
@@ -440,6 +506,7 @@ class ComparisonRegions(RegionsTable):
             region1 = regions[(region2.chromosome, region2.start, region2.end)]
             v1 = getattr(region1, attribute)
             v2 = getattr(region2, attribute)
+
             v = comparison_regions.compare(v1, v2)
             if log:
                 v = np.log2(v)
@@ -595,6 +662,47 @@ def hic_pca(*hics, sample_size=None, region=None, strategy='variance', scale=Tru
             ignore_zeros=False, oe_enrichment=None, min_distance=None, max_distance=None,
             background_ligation=False, min_libraries_above_background=1,
             **kwargs):
+    """
+    Run a PCA analysis on a set of Hi-C matrices.
+
+    Note: this is not a compartment analysis. Use :class:`~ABCompartmentMatrix` for
+    that purpose.
+
+    :param hics: Two or more Hi-C objects
+    :param sample_size: Optional. Set an upper limit on the number of edges sampled
+                        for this analysis. If not specified, will use all applicable
+                        edges. Used in conjunction with ``strategy`` to determine
+                        which edges to prioritise
+    :param region: Optionally specify a region string to limit the PCA to that region.
+    :param strategy: Sort order of edges. Used in conjunction with ``sample_size``.
+                     One of "variance" (default), "fold-change", or "passthrough".
+                     variance: edges sorted by variance of contact strength
+                     across samples; fold-change: edges sorted by size of fold-change
+                     of contact strength across samples; passthrough: unsorted, edges
+                     appear in order they are stored in the object
+    :param scale: If ``True`` (default), the matrix values are scaled to their sequencing
+                  depth before running PCA. If you are using the default normalisation,
+                  matrix entries correspond to contact probabilities and the margins are
+                  equal to 1 and there is not Need for scaling, so you can set this to
+                  ``False`` in order to save computational time.
+    :param log: Log-transform contact strength prior to PCA
+    :param ignore_zeros: Only use contacts that are non-zero in all samples
+    :param oe_enrichment: Used for "fold-change" ``strategy``, at least on edge must
+                          have an O/E of this value or larger.
+    :param min_distance: regions must be at least this far apart (in base pairs) to be
+                         used for PCA
+    :param max_distance: regions must be at least this close together (in base pairs) to be
+                         used for PCA
+    :param background_ligation: Use the average inter-chromosomal contact strength as
+                                background ligation signal and only use pixels where at
+                                least ``min_libraries_above_background`` samples have
+                                an O/E signal above background
+    :param min_libraries_above_background: Minimum number of libraries/samples that
+                                           must have an O/E above background ligation
+                                           signal for each pixel.
+    :param kwargs: Keyword arguments passed to :func:`~fanc.matrix.RegionMatrixTable.edges`
+    :return: sklearn PCA object, PCA result
+    """
 
     strategies = {
         'variance': LargestVarianceSelector(),
